@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXString.cpp,v 1.218 2006/01/22 17:58:42 fox Exp $                       *
+* $Id: FXString.cpp,v 1.218.2.1 2006/08/15 05:03:16 fox Exp $                       *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -166,7 +166,7 @@ FXint wcvalidate(const FXnchar *string,FXint pos){
 
 // Advance to next utf8 character start
 FXint wcinc(const FXchar* string,FXint pos){
-  return (FXISUTF(string[++pos]) || FXISUTF(string[++pos]) || FXISUTF(string[++pos]) || FXISUTF(string[++pos]) || FXISUTF(string[++pos]) || ++pos), pos;
+  return (string[pos++]==0 || FXISUTF(string[pos]) || string[pos++]==0 || FXISUTF(string[pos]) || string[pos++]==0 || FXISUTF(string[pos]) || string[pos++]==0 || FXISUTF(string[pos]) || string[pos++]==0 || FXISUTF(string[pos]) || ++pos), pos;
   }
 
 
