@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXTopWindow.cpp,v 1.175.2.1 2006/05/10 13:18:13 fox Exp $                    *
+* $Id: FXTopWindow.cpp,v 1.175.2.6 2007/03/29 18:01:51 fox Exp $                    *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -190,6 +190,18 @@ void FXTopWindow::create(){
   if(xid){
     if(getApp()->isInitialized()){
 
+    // Only shrinkable; size may not be above default size
+    if((options&DECOR_SHRINKABLE) && !(options&DECOR_STRETCHABLE)){
+      if(width>getDefaultWidth()) width=getDefaultWidth();
+      if(height>getDefaultHeight()) height=getDefaultHeight();
+      }
+
+    // Only stretchable; size may not be below default size
+    else if((options&DECOR_STRETCHABLE) && !(options&DECOR_SHRINKABLE)){
+      if(width<getDefaultWidth()) width=getDefaultWidth();
+      if(height<getDefaultHeight()) height=getDefaultHeight();
+      }
+
 #ifndef WIN32
       // Catch delete window
       Atom protocols[3];
@@ -201,43 +213,46 @@ void FXTopWindow::create(){
       // Set position for Window Manager
       XSizeHints size;
 
-      size.flags=USSize|PSize|PWinGravity;      // Let Window Manager place it
-      size.x=0;
-      size.y=0;
-      //if(xpos!=0 || ypos!=0){                   // Force explicit position
-        size.flags|=USPosition|PPosition;
-      //  }
-        size.x=xpos;
-        size.y=ypos;
-      size.min_width=0;
-      size.min_height=0;
-      size.base_width=0;
-      size.base_height=0;
-      if(!(options&DECOR_SHRINKABLE)){          // Can not shrink, so set min size
-        size.flags|=PMinSize|PBaseSize;
-        size.min_width=getDefaultWidth();
-        size.min_height=getDefaultHeight();
-        size.base_width=width;
-        size.base_height=height;
-        }
-      size.max_width=0;
-      size.max_height=0;
-      if(!(options&DECOR_STRETCHABLE)){         // Can not grow, so set max size
-        size.flags|=PMaxSize;
-        size.max_width=getDefaultWidth();
-        size.max_height=getDefaultHeight();
-        }
+      // Placement hints
+      size.flags=USSize|PSize|PWinGravity|USPosition|PPosition;
+      size.x=xpos;
+      size.y=ypos;
       size.width=width;
       size.height=height;
+      size.min_width=0;
+      size.min_height=0;
+      size.max_width=0;
+      size.max_height=0;
       size.width_inc=0;
       size.height_inc=0;
       size.min_aspect.x=0;
       size.min_aspect.y=0;
       size.max_aspect.x=0;
       size.max_aspect.y=0;
+      size.base_width=0;
+      size.base_height=0;
       size.win_gravity=NorthWestGravity;        // Tim Alexeevsky <realtim@mail.ru>
       size.win_gravity=StaticGravity;           // Account for border (ICCCM)
 
+      // Apply resize limitations
+      if(!(options&DECOR_SHRINKABLE)){
+        if(!(options&DECOR_STRETCHABLE)){       // Cannot change at all
+          size.flags|=PMinSize|PMaxSize;
+          size.min_width=size.max_width=width;
+          size.min_height=size.max_height=height;
+          }
+        else{                                   // Cannot get smaller than default
+          size.flags|=PMinSize;
+          size.min_width=getDefaultWidth();
+          size.min_height=getDefaultHeight();
+          }
+        }
+      else if(!(options&DECOR_STRETCHABLE)){    // Cannot get larger than default
+        size.flags|=PMaxSize;
+        size.max_width=getDefaultWidth();
+        size.max_height=getDefaultHeight();
+        }
+
       // Set hints
       XSetWMNormalHints(DISPLAY(getApp()),xid,&size);
 
@@ -417,53 +432,44 @@ void FXTopWindow::place(FXuint placement){
   rh=getRoot()->getHeight();
 #else
   RECT rect;
-#if (WINVER >= 0x500) || ((defined _WIN32_WINDOWS) && (_WIN32_WINDOWS >= 0x410))
-  HINSTANCE user32;
-  typedef BOOL (WINAPI* PFN_GETMONITORINFOA)(HMONITOR, LPMONITORINFO);
-  typedef HMONITOR (WINAPI* PFN_MONITORFROMRECTA)(LPRECT, DWORD);
-  PFN_GETMONITORINFOA GetMonitorInfoA;
-  PFN_MONITORFROMRECTA MonitorFromRectA;
+  MYMONITORINFO minfo;
+  HANDLE monitor;
 
-  // Suggested by "Daniel Gehriger" <gehriger@linkcad.com>
-  // The API does not exist on older Windows NT and 95, so
-  // We can't even link it, let alone call it.
-  // The solution is to ask the DLL if the function exists.
-  // And another patch from Lothar Scholtz; now it works!
-  if((user32=LoadLibraryA("User32")) && (GetMonitorInfoA=reinterpret_cast<PFN_GETMONITORINFOA>(GetProcAddress(user32,"GetMonitorInfoA"))) && (MonitorFromRectA=reinterpret_cast<PFN_MONITORFROMRECTA>(GetProcAddress(user32,"MonitorFromRect")))){
-    MONITORINFOEXA minfo;
-    HMONITOR hMon;
-    if(placement == PLACEMENT_CURSOR){
-      // Use mouse position to select screen.
-      getRoot()->getCursorPosition(x,y,state);
-      rect.left=x;
-      rect.right=x+1;
-      rect.top=y;
-      rect.bottom=y+1;
-      }
-    else{
-      // Use owner to select screen.
-      over=getOwner()?getOwner():getRoot();
-      over->translateCoordinatesTo(ox,oy,getRoot(),0,0);
-      ow=over->getWidth();
-      oh=over->getHeight();
-      rect.left=ox;
-      rect.right=ox+ow;
-      rect.top=oy;
-      rect.bottom=oy+oh;
-      }
-    hMon=MonitorFromRectA(&rect,MONITOR_DEFAULTTOPRIMARY);
+  // Use mouse position to select screen
+  if(placement!=PLACEMENT_OWNER){
+    getRoot()->getCursorPosition(x,y,state);
+    rect.left=x;
+    rect.right=x+1;
+    rect.top=y;
+    rect.bottom=y+1;
+    }
+
+  // Use owner to select screen
+  else{
+    over=getOwner()?getOwner():getRoot();
+    over->translateCoordinatesTo(ox,oy,getRoot(),0,0);
+    ow=over->getWidth();
+    oh=over->getHeight();
+    rect.left=ox;
+    rect.right=ox+ow;
+    rect.top=oy;
+    rect.bottom=oy+oh;
+    }
+
+  // Get monitor info if we have this API
+  monitor=fxMonitorFromRect(&rect,MONITOR_DEFAULTTOPRIMARY);
+  if(monitor){
     memset(&minfo,0,sizeof(minfo));
     minfo.cbSize=sizeof(minfo);
-    GetMonitorInfoA(hMon,&minfo);
+    fxGetMonitorInfo(monitor,&minfo);
     rx=minfo.rcWork.left;
     ry=minfo.rcWork.top;
     rw=minfo.rcWork.right-minfo.rcWork.left;
     rh=minfo.rcWork.bottom-minfo.rcWork.top;
     }
-  else
-#endif
-    {
-    // On Win95 and WinNT, we have to use the following
+
+  // Otherwise use the work-area
+  else{
     SystemParametersInfo(SPI_GETWORKAREA,sizeof(RECT),&rect,0);
     rx=rect.left;
     ry=rect.top;
@@ -511,8 +517,8 @@ void FXTopWindow::place(FXuint placement){
       // Adjust so dialog is fully visible
       if(wx<rx) wx=rx+10;
       if(wy<ry) wy=ry+10;
-      if(wx+ww>rw) wx=rw-ww-10;
-      if(wy+wh>rh) wy=rh-wh-10;
+      if(wx+ww>rx+rw) wx=rx+rw-ww-10;
+      if(wy+wh>ry+rh) wy=ry+rh-wh-10;
       break;
 
     // Place centered over the owner
@@ -535,8 +541,8 @@ void FXTopWindow::place(FXuint placement){
       // Adjust so dialog is fully visible
       if(wx<rx) wx=rx+10;
       if(wy<ry) wy=ry+10;
-      if(wx+ww>rw) wx=rw-ww-10;
-      if(wy+wh>rh) wy=rh-wh-10;
+      if(wx+ww>rx+rw) wx=rx+rw-ww-10;
+      if(wy+wh>ry+rh) wy=ry+rh-wh-10;
       break;
 
     // Place centered on the screen
@@ -553,8 +559,8 @@ void FXTopWindow::place(FXuint placement){
       // Adjust so dialog is fully visible
       if(wx<rx) wx=rx+10;
       if(wy<ry) wy=ry+10;
-      if(wx+ww>rw) wx=rw-ww-10;
-      if(wy+wh>rh) wy=rh-wh-10;
+      if(wx+ww>rx+rw) wx=rx+rw-ww-10;
+      if(wy+wh>ry+rh) wy=ry+rh-wh-10;
       break;
 
     // Place maximized
@@ -898,7 +904,7 @@ FXbool FXTopWindow::close(FXbool notify){
   register FXWindow *window;
 
   // Ask target if desired
-  if(!notify || !target || !message || !target->tryHandle(this,FXSEL(SEL_CLOSE,message),NULL)){
+  if(!notify || !target || !target->tryHandle(this,FXSEL(SEL_CLOSE,message),NULL)){
 
     // Target will receive no further messages from us
     setTarget(NULL);
